
import java.math.BigDecimal;
import java.util.GregorianCalendar;

import javax.persistence.EntityManager;
import javax.persistence.Query;

import book.entities.Book;
import book.util.Utils;

public class Main {

    public static EntityManager em;

    public static void main(String[] args) {
        withDbTransaction(() -> {
            deleteRecords();

            Book book = new Book("title1",
            		"author1",
            		new GregorianCalendar(1234, 5, 6),
            		123,
            		new BigDecimal(1234),
        			Book.StockStatus.IN_STOCK);
            em.persist(book);

            Utils.printRecords(em);
        });
    }

    private static void withDbTransaction(Runnable transaction) {
        em = Utils.getEntityManager("bookPU");

        // Begin transaction
        em.getTransaction().begin();

        // The caller has specified what to do, run those steps now...
        transaction.run();

        // Commit the transaction and close the entity manager
        em.getTransaction().commit();
        em.close();
    }

	private static void deleteRecords() {
        // Bulk delete with criteria API
        Query query = em.createQuery("DELETE FROM Book");
        int removedItems = query.executeUpdate();

        if (removedItems > 0) {
            System.out.println(removedItems + " items removed.");
        }
    }

}
