package book.entities;

import static javax.persistence.EnumType.STRING;
import static javax.persistence.GenerationType.AUTO;
import static javax.persistence.TemporalType.DATE;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Calendar;

import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Temporal;

@Entity
public class Book implements Serializable {
	public static enum StockStatus { IN_STOCK, OUT_OF_STOCK, UNKNOWN };

	private static final long serialVersionUID = -7384731035271637295L;

	@Id @GeneratedValue(strategy=AUTO)
	private int id;

	@Basic(optional=false)
	@Column(length=255)
	private String title;

	@Basic(optional=false)
	@Column(length=255)
	private String author;

	@Temporal(DATE)
	private Calendar publishedAt;

	private int pages;

	@Column(precision = 10, scale = 2)
	BigDecimal price;

	@Enumerated(STRING)
	StockStatus stockStatus;

	@Override
	public String toString() {
		return "Book [id=" + id + ", title=" + title + ", author=" + author + ", publishedAt=" + publishedAt
				+ ", pages=" + pages + ", price=" + price + ", stockStatus=" + stockStatus + "]";
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getAuthor() {
		return author;
	}

	public void setAuthor(String author) {
		this.author = author;
	}

	public Calendar getPublishedAt() {
		return publishedAt;
	}

	public void setPublishedAt(Calendar publishedAt) {
		this.publishedAt = publishedAt;
	}

	public int getPages() {
		return pages;
	}

	public void setPages(int pages) {
		this.pages = pages;
	}

	public BigDecimal getPrice() {
		return price;
	}

	public void setPrice(BigDecimal price) {
		this.price = price;
	}

	public StockStatus getStockStatus() {
		return stockStatus;
	}

	public void setStockStatus(StockStatus stockStatus) {
		this.stockStatus = stockStatus;
	}

	public static long getSerialversionuid() {
		return serialVersionUID;
	}


	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + id;
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Book other = (Book) obj;
		if (id != other.id)
			return false;
		return true;
	}

	public Book(String title, String author, Calendar publishedAt, int pages, BigDecimal price,
			StockStatus stockStatus) {
		this.title = title;
		this.author = author;
		this.publishedAt = publishedAt;
		this.pages = pages;
		this.price = price;
		this.stockStatus = stockStatus;
	}

	public Book() {
	}
}
